==> jc-1.4.0.tar.gz: soot/tagkit/FloatConstantValueTag.h <==
// public class soot.tagkit.FloatConstantValueTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class f2c6a1d8a2791b96 soot_tagkit_FloatConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_FloatConstantValueTag_H_
#define _JC_soot_tagkit_FloatConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_FloatConstantValueTag$sub_refs	_jc_soot_tagkit_FloatConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs	_jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$refs	_jc_soot_tagkit_FloatConstantValueTag$refs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$nonrefs	_jc_soot_tagkit_FloatConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$object	_jc_soot_tagkit_FloatConstantValueTag$object;

typedef const struct _jc_soot_tagkit_FloatConstantValueTag$vmethods	_jc_soot_tagkit_FloatConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_FloatConstantValueTag$vtable	_jc_soot_tagkit_FloatConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_FloatConstantValueTag$vtype	_jc_soot_tagkit_FloatConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_FloatConstantValueTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *, jint);

// Virtual methods
extern jfloat _jc_soot_tagkit_FloatConstantValueTag$method$getFloatValue$e8750be4084087d4(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *);
extern jint _jc_soot_tagkit_FloatConstantValueTag$method$getRawBits$546d9f676ea2e009(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_FloatConstantValueTag$method_info$getFloatValue$e8750be4084087d4;
extern _jc_method _jc_soot_tagkit_FloatConstantValueTag$method_info$getRawBits$546d9f676ea2e009;

// Virtual methods structure
struct _jc_soot_tagkit_FloatConstantValueTag$vmethods {
	jfloat	(*getFloatValue$e8750be4084087d4)(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *);
	jint	(*getRawBits$546d9f676ea2e009)(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *);
};

// Vtable
struct _jc_soot_tagkit_FloatConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_FloatConstantValueTag$vmethods	soot_tagkit_FloatConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_FloatConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_FloatConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_FloatConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_FloatConstantValueTag$refs {
    _jc_soot_tagkit_FloatConstantValueTag$sub_refs	soot_tagkit_FloatConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_FloatConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs	soot_tagkit_FloatConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_FloatConstantValueTag$object {
	_jc_soot_tagkit_FloatConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_FloatConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_FloatConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_FloatConstantValueTag$vtype _jc_soot_tagkit_FloatConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_FloatConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_FloatConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_FloatConstantValueTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/FloatConstantValueTag.h <==
// public class soot.tagkit.FloatConstantValueTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class f2c6a1d8a2791b96 soot_tagkit_FloatConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_FloatConstantValueTag_H_
#define _JC_soot_tagkit_FloatConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_FloatConstantValueTag$sub_refs	_jc_soot_tagkit_FloatConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs	_jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$refs	_jc_soot_tagkit_FloatConstantValueTag$refs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$nonrefs	_jc_soot_tagkit_FloatConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_FloatConstantValueTag$object	_jc_soot_tagkit_FloatConstantValueTag$object;

typedef const struct _jc_soot_tagkit_FloatConstantValueTag$vmethods	_jc_soot_tagkit_FloatConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_FloatConstantValueTag$vtable	_jc_soot_tagkit_FloatConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_FloatConstantValueTag$vtype	_jc_soot_tagkit_FloatConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_FloatConstantValueTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jfloat _jc_soot_tagkit_FloatConstantValueTag$method$getFloatValue$e8750be4084087d4(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_FloatConstantValueTag$method$getRawBits$546d9f676ea2e009(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_FloatConstantValueTag$method_info$getFloatValue$e8750be4084087d4;
extern _jc_method _jc_soot_tagkit_FloatConstantValueTag$method_info$getRawBits$546d9f676ea2e009;

// Virtual methods structure
struct _jc_soot_tagkit_FloatConstantValueTag$vmethods {
	jfloat	(*getFloatValue$e8750be4084087d4)(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *) _JC_JCNI_ATTR;
	jint	(*getRawBits$546d9f676ea2e009)(_jc_env *, struct _jc_soot_tagkit_FloatConstantValueTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_FloatConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_FloatConstantValueTag$vmethods	soot_tagkit_FloatConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_FloatConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_FloatConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_FloatConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_FloatConstantValueTag$refs {
    _jc_soot_tagkit_FloatConstantValueTag$sub_refs	soot_tagkit_FloatConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_FloatConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_FloatConstantValueTag$sub_nonrefs	soot_tagkit_FloatConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_FloatConstantValueTag$object {
	_jc_soot_tagkit_FloatConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_FloatConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_FloatConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_FloatConstantValueTag$vtype _jc_soot_tagkit_FloatConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_FloatConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_FloatConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_FloatConstantValueTag_H_ */
